@@ -1,6 +1,6 @@
 <?php
 /*
- V5.12 30 June 2011   (c) 2000-2011 John Lim (jlim#natsoft.com). All rights reserved.
+ V5.15 19 Jan 2012  (c) 2000-2012 John Lim (jlim#natsoft.com). All rights reserved.
   Released under both BSD license and Lesser GPL library license. 
   Whenever there is any discrepancy between the two licenses, 
   the BSD license will take precedence.
@@ -958,7 +958,7 @@ class ADORecordSet_postgres64 extends ADORecordSet{
 	{
 		if ($blob === NULL) return NULL;
 //		eval('$realblob="'.adodb_str_replace(array('"','$'),array('\"','\$'),$blob).'";');
-		return $realblob;	
+		return pg_unescape_bytea($blob);
 	}
 	
 	function _fixblobs()
