@@ -2,7 +2,7 @@
 <body>
 <?php
 /* 
-V4.80 8 Mar 2006  (c) 2000-2008 John Lim (jlim#natsoft.com). All rights reserved.
+V4.80 8 Mar 2006  (c) 2000-2012 John Lim (jlim#natsoft.com). All rights reserved.
   Released under both BSD license and Lesser GPL library license. 
   Whenever there is any discrepancy between the two licenses, 
   the BSD license will take precedence. 
@@ -10,7 +10,7 @@ V4.80 8 Mar 2006  (c) 2000-2008 John Lim (jlim#natsoft.com). All rights reserved
 	
   Latest version is available at http://adodb.sourceforge.net
 */
-error_reporting(63);
+error_reporting(E_ALL | E_STRICT);
 include("../adodb.inc.php");
 include("../tohtml.inc.php");
 
